@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: Copyright (c) 2004-2024 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
+ * SPDX-FileCopyrightText: Copyright (c) 2004-2025 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  * SPDX-License-Identifier: MIT
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -86,6 +86,7 @@
 #define NV_PCI_SUBID_VENDOR_SONY          0x104D
 #define NV_PCI_SUBID_VENDOR_BITLAND       0x1642
 #define NV_PCI_SUBID_VENDOR_PC_PARTNER    0x174B
+#define NV_PCI_SUBID_VENDOR_CAVIUM        0x177D
 #define NV_PCI_SUBID_VENDOR_NZXT          0x1D96
 
 // XXX CKEANUP TO REMOVE IN FAVOR OF NV_PCI_SUBID_VENDOR_*
@@ -146,6 +147,9 @@
 #define PCI_VENDOR_ID_ARM           0x13B5
 #define PCI_VENDOR_ID_HYGON         0x1D94
 #define PCI_VENDOR_ID_ALIBABA       0x1DED
+#define PCI_VENDOR_ID_SIFIVE        0xF15E
+#define PCI_VENDOR_ID_PLDA          0x1556
+#define PCI_VENDOR_ID_PHYTIUM       0x1DB7
 
 #define NV_PCI_DEVID_DEVICE                    31:16  /* RW--F */
 #define NV_PCI_SUBID_DEVICE                    31:16  /* RW--F */
@@ -168,6 +172,11 @@
 // A16
 #define NV_PCI_SUBID_DEVICE_PG171_SKU200             0x14A9
 
+// NVIDIA B200
+#define NV_PCI_SUBID_DEVICE_PG525_SKU220             0x1999
+#define NV_PCI_SUBID_DEVICE_PG525_SKU225             0x199B
+#define NV_PCI_SUBID_DEVICE_PG525_SKU230             0x20DA
+
 ///////////////////////////////////////////////////////////////////////////////////////////
 //
 // CHIPSET IDs
@@ -192,6 +201,10 @@
 //Tylersburg Congurations
 #define TYLERSBURG_DEVID                    0x3406
 
+// Intel Barlow Ridge TB5 device IDs
+#define DEVICE_ID_INTEL_BARLOW_RIDGE_5786_EGPU     0x5786
+#define DEVICE_ID_INTEL_BARLOW_RIDGE_57A4_EGPU     0x57A4
+
 // Intel Grantsdale definitions
 #define DEVICE_ID_INTEL_2580_HOST_BRIDGE    0x2580
 #define DEVICE_ID_INTEL_2581_ROOT_PORT      0x2581
@@ -288,10 +301,6 @@
 // Intel Ivy Bridge E definitions
 #define DEVICE_ID_INTEL_0E00_HOST_BRIDGE    0x0E00
 
-// Intel Haswell definitions
-#define DEVICE_ID_INTEL_0C00_HASWELL_HOST_BRIDGE        0x0C00
-#define DEVICE_ID_INTEL_0C04_HASWELL_HOST_BRIDGE        0x0C04
-
 // Intel PCH definitions
 #define DEVICE_ID_INTEL_9D10_PCH_BRIDGE     0x9d10
 #define DEVICE_ID_INTEL_9D18_PCH_BRIDGE     0x9d18
@@ -446,6 +455,9 @@
 #define FOXCONN_EINSTEIN_64_DEVID           0xA1C1
 #define FOXCONN_EINSTEIN_64_SSDEVID         0x7270
 
+// Cavium, Inc. CN99xx [ThunderX2]  [177d:af00]
+#define CAVIUM_X2_DEVID                     0xAF00
+
 // Lenovo Tomcat/Falcon/Hornet Workstations
 #define LENOVO_TOMCAT_DEVID                 0x1B81
 #define LENOVO_TOMCAT_SSDEVID               0x104e
@@ -610,6 +622,7 @@ enum {
 ,     CS_NVIDIA_T234
 ,     CS_NVIDIA_T23x
 ,     CS_NVIDIA_TH500
+,     CS_NVIDIA_T264
 ,     CS_MARVELL_THUNDERX2
 ,     CS_REDHAT_QEMU
 ,     CS_AMPERE_EMAG
@@ -631,10 +644,22 @@ enum {
 ,     CS_INTEL_18DC
 ,     CS_INTEL_7A04
 ,     CS_INTEL_5795
-,     CS_AMPERE_AMPEREONE
+,     CS_RESERVED_1
+,     CS_SIFIVE_FU740_C000
+,     CS_PLDA_XPRESSRICH_AXI_REF
+,     CS_AMPERE_AMPEREONE160
+,     CS_PHYTIUM_S5000
+,     CS_RESERVED_2
+,     CS_RESERVED_3
+,     CS_AMD_RPH
+,     CS_INTEL_B660
+,     CS_AMPERE_AMPEREONE192
 ,     CS_MAX_PCIE
 };
 
+// Chip IDs for Tegra SoCs
+#define NV_CHIP_ID_T234 0x2350
+
 enum {
     RP_UNKNOWN = 0
 ,   RP_BROADCOM_HT2100
